==> dl.php?src=linea21_1_8.zip: linea21/languages/it/lang_dashboard.utf-8.php <==
<?php
/**
 * @package linea21\languages\it
 * @author $Author$ - Alessandra Rossi & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['dashboard']['section'] = "pannello di controllo";

/*	nommage des modules
 *  	*/
$lang['dashboard']['name'] = "valore";
$lang['dashboard']['name_pluriel'] = 'valore(i)';
$lang['dashboard']['confirm_add'] = "Aggiunta di un valore realizzata con successo\n";
$lang['dashboard']['confirm_mod'] = "Modifica del valore realizzata con successo\n";
$lang['dashboard']['confirm_sup'] = "Eliminazione del valore realizzata con successo\n";




/*	nommage public
 *  	*/
$lang['dashboard']['list_public']="Pannello di controllo";

$lang['dashboard']['h1_public_comment']="Il pannello di controllo rappresenta il bilancio di sviluppo sostenibile della vostra città (filtrato per scala).<br />";
$lang['dashboard']['h1_public_comment_anim']="Il pannello di controllo rappresenta il bilancio di sviluppo sostenibile della vostra città.<br />";

$lang['dashboard']['mode_aff']="Modalità di visualizzazione";
$lang['dashboard']['mode_by_project']="Project view"; // @todo translation
$lang['dashboard']['mode_by_finality']="Finality view"; // @todo translation
$lang['dashboard']['mode_aff_info']="Informazioni generali";
$lang['dashboard']['mode_aff_evaluation']="Criteri di valutazione";
$lang['dashboard']['mode_aff_provider']="Fornitore";
$lang['dashboard']['mode_aff_rules']="Regolamentazione";
$lang['sdi']['goal_public']="Gli obiettivi di chi avete eletto";
$lang['sdi']['consulting_public']="Consigli per migliorare questo indicatore";

$lang['dashboard']['tab-attached']='Dashboard'; // @todo translation
$lang['dashboard']['tab-not-attached']='Autonomous indicators'; // @todo translation
$lang['dashboard']['tab-all']='All'; // @todo translation

$lang['dashboard']['export_to_excel']='Export to Excel'; // @todo translation

/* informations affichages tableau
 * */
$lang['dashboard']['list_public_summary']="Valori degli indicatori relativi ai %s";
$lang['dashboard']['graphic_value']="valore grafico";
$lang['dashboard']['numeric_value']="valore numerico";
$lang['dashboard']['tendencies_value']="tendenze";
$lang['dashboard']['label_value']="etichetta dell'indicatore";

$lang['dashboard']['evaluation_values_summary']="Valori dei criteri di valutazione per l'indicatore corrente";
$lang['dashboard']['all_values_summary']="Sommario dei valori dell'indicatore corrente";

$lang['dashboard']['multivalue_label']="label"; // @todo translation
$lang['dashboard']['multivalue_value']="value"; // @todo translation
$lang['dashboard']['multivalue_total']="total"; // @todo translation

$lang['dashboard']['to_detail_chart']="see pie chart"; // @todo translation
$lang['dashboard']['negative_values_notice']="[negative values not displayed]"; // @todo translation

/*	nommage rubrique module
 *  	*/
$lang['dashboard']['add'] = "Aggiunta di una " . $lang['dashboard']['name'];
$lang['dashboard']['rap'] = "Pubblicazione di un rapporto globale";
$lang['dashboard']['mod'] = "Modifica del valore";
$lang['dashboard']['sup'] = "Eliminazione di una " . $lang['dashboard']['name'];
$lang['dashboard']['det'] = "Valori dell'indicatore";
$lang['dashboard']['list'] = "Pannello di controllo ";


/*	nommage rubrique add / mod /det
 *  	*/
$lang['dashboard']['add_title1'] = "Inserimento della nuova " . $lang['dashboard']['name'];
$lang['dashboard']['recap_commment'] = "nessun commento";
$lang['dashboard']['confirmation'] = "conferma l'iscrizione";


/*	nommage rubrique sup
 *  	*/
$lang['dashboard']['sup_value_warning'] = "Sei sicuro di voler sopprimere definitivamente questa " . $lang['dashboard']['name'] . "?";


/*	nommage élément rubrique

*  	*/
$lang['dashboard']['value'] = "valore dell'indicatore";
$lang['dashboard']['threshold_value']="valore soglia";
$lang['dashboard']['historic'] = "Bilancio dell'indicatore";
$lang['dashboard']['rep_graph'] = "Rappresentazione grafica dell'indicatore";
$lang['dashboard']['sdi_info'] = "nome dell'indicatore";
$lang['dashboard']['scale'] = "scala di misura del valore";
$lang['dashboard']['date'] = "data di pubblicazione";
$lang['dashboard']['day'] = "giorno";
$lang['dashboard']['month'] = "mese";
$lang['dashboard']['year'] = "anno";
$lang['dashboard']['rate'] = "percentage"; // @todo translation
$lang['dashboard']['comment'] = "comment"; // @todo translation
$lang['dashboard']['comment_status'] = "comment status"; // @todo translation
$lang['dashboard']['public'] = "public"; // @todo translation
$lang['dashboard']['private'] = "private"; // @todo translation
$lang['dashboard']['previous_value'] = "previous value : %s"; // @todo translation

/*	nommage quickbox
 *  	*/
$lang['dashboard']['qb_add_title'] = " ultime aggiunte effettuate nel : ";
$lang['dashboard']['qb_mod_title'] = " ultime modifiche effettuate nel : ";




/*	rapport
 *  	*/
$lang['dashboard']['rap_scale_choice'] = "Scegliere le scale";
$lang['dashboard']['rap_scale_all'] = "Aggiungere tutte le scale del pannello di controllo";
$lang['dashboard']['rap_scale_det'] = "Scegliere le scale precise da includere";
$lang['dashboard']['rap_sdi_choice'] = "Scegliere gli indicatori";
$lang['dashboard']['rap_sdi_all'] = "Aggiungere tutti gli indicatori del pannello di controllo";
$lang['dashboard']['rap_sdi_det'] = "Scegliere gli indicatori precisi da includere nel rapporto";
$lang['dashboard']['rap_comp_choice'] = "Scegliere le informazioni complementari";
$lang['dashboard']['rap_graph_values'] = "Aggiungere i grafici di valore nel rapporto ";
$lang['dashboard']['rap_table_values'] = "Aggiungere l'insieme dei valori per ogni indicatore";
$lang['dashboard']['rap_notpublished_values'] = "Far comparire i valori non pubblicati";
$lang['dashboard']['rap_provider_info'] = "Aggiungere le informazioni dei fornitori per ogni indicatore";
$lang['dashboard']['rap_rules_info'] = "Aggiungere le informazioni di regolamentazione per ogni indicatore";
$lang['dashboard']['rap_eval_info'] = "Aggiungere i criteri di valutazione per ogni indicatore";
$lang['dashboard']['rap_summary_info'] = "Generare un indice";
$lang['dashboard']['rap_publi_info'] = "Aggiungere le informazioni per la generazione del documento alla fine del rapporto";
$lang['dashboard']['rap_author'] = "Autore del rapporto";
$lang['dashboard']['rap_mail_author'] = "mail dell'autore";
$lang['dashboard']['rap_service'] = "Ufficio";
$lang['dashboard']['rap_adress'] = "Indirizzo completo";
$lang['dashboard']['rap_title'] = "Titolo del rapporto";
$lang['dashboard']['rap_no_values_for'] = 'nessun valore per le scale seguenti : ';
$lang['dashboard']['rap_insuffisant_values'] = 'Dati insufficienti per la generazioni dei grafici sulle scale seguenti :';
$lang['dashboard']['rap_scale'] = "Scale selezionate";
$lang['dashboard']['rap_indicators'] = "indicatori selezionati";
$lang['dashboard']['rap_generated'] = "rapporto generato in ";
$lang['dashboard']['rap_infopubli'] = "Informazioni di pubblicazione";
$lang['dashboard']['rap_summary'] = "Indice - accesso rapido";
$lang['dashboard']['rap_save'] = "salva";
$lang['dashboard']['select_by_finalities'] = "... by finalities"; // @todo translation
$lang['dashboard']['select_by_association'] = "... by association"; // @todo translation
$lang['dashboard']['indicator-attached']='Indicators attached to dashboard'; // @todo translation
$lang['dashboard']['indicator-not-attached']='Indicators not attached to dashboard'; // @todo translation

/*	divers
 *  	*/
$lang['dashboard']['select_choice'] = "-- Scegli nella lista sottostante --";
$lang['dashboard']['facultatif'] = "facoltativo";
$lang['dashboard']['aff_dashboard_e'] = "Visualizzare i criteri di valutazione";
$lang['dashboard']['aff_dashboard_r'] = "Visualizzare le referenze regolamentari";
$lang['dashboard']['aff_dashboard_p'] = "Visualizzare le coordinate del fornitore";
$lang['dashboard']['novalue'] = "Nessun valore è disponibile";
$lang['dashboard']['value_tendance'] = "Tendenza globale dell'indicatore";
$lang['dashboard']['tendance_asc'] = "ascendente";
$lang['dashboard']['tendance_desc'] = "discendente";
$lang['dashboard']['all_value'] = "Insieme dei valori per questo indicatore";
$lang['dashboard']['barre'] = "Posizionamento dell'indicatore in rapporto al suo valore soglia";
$lang['dashboard']['global_value'] = "valore globale";
$lang['dashboard']['det_sdi'] = "visualizzare le informazioni generali dell'indicatore";
$lang['dashboard']['det_sdi2'] = "Informazioni generali";


/*	messages
 *  	*/


$lang['dashboard']['object_notvalue'] = "Devi assolutamente inserire un valore numerico per questo indicatore.";
$lang['dashboard']['object_notgoodvalue'] = "Devi assolutamente inserire un valore compreso nei limiti di misura.";


/*	rubrique d'aide
 *  	*/
$lang['dashboard']['help_add1'] = "Per aggiungere un valore, devi inserire ciascuno di questi parametri nel modulo qui sotto";
$lang['dashboard']['help_add2'] = "Puoi cliccare su \"informazioni di misura\" per ottenere i valori soglia minimale, massimale e la frequenza di raccolta di questo indicatore";
$lang['dashboard']['help_add3'] = "Puoi cliccare su \"" . $lang['dashboard']['all_value'] . "\" per visualizzare tutti i valori di questo indicatore per questa scala";
$lang['dashboard']['help_add4'] = "Se il riepilogo non ti soddisfa, puoi cliccare su \"modifica i parametri\" per modificarlo";
$lang['dashboard']['help_add5'] = "Devi assolutamente inserire un valore numerico compreso tra i valori minimali e massimali previsti da questo indicatore";
$lang['dashboard']['help_add6'] = "I campi contrassegnati da un asterisco sono obbligatori";


$lang['dashboard']['help_list1'] = "Per visualizzare i valori di una coppia indicatore/scala nel dettaglio, clicca sul nome dell'indicatore.";
$lang['dashboard']['help_list2'] = "Puoi aggiungere un valore a una coppia indicatore/scala cliccando sull'icona d'aggiunta ad essa associata.";
$lang['dashboard']['help_list3'] = "Puoi selezionare un'altra scala, il pannello di controllo verrà aggiornato : l'insieme degli indicatori di questa scala apparirà sul pannello di controllo.";
$lang['dashboard']['help_list4'] = "Ogni indicatore è associato a un contatore che permette una visione globale del pannello di controllo per una data scala : se il cursore del contatore è al di là della soglia, l'ultimo valore registarto per questo indicatore ha superato la soglia stabilita";
$lang['dashboard']['help_list5'] = "Se l'indicatore, per una data scala, conta più di due valori, un'icona di trend apparirà accanto al contatore";
$lang['dashboard']['help_list6'] = "L'ultimo valore dell'indicatore, per una data scala, è richiamato accanto al contatore.";
$lang['dashboard']['help_list7'] = "Un contatore globale è presente nella parte alta della pagina e permette una visione globale del pannello di controllo per una data scala.";
$lang['dashboard']['help_list8'] = "Trucco : lasciare immobile il cursore sui differenti elementi della pagina mostrerà delle informazioni complementari.";


$lang['dashboard']['help_mod1'] = "Per modificare un valore, puoi modificare ciascuno di questi parametri nel modulo qui sotto";
$lang['dashboard']['help_mod2'] = "Puoi cliccare su \"informazioni di misura\" per ottenere i valori soglia minimale, massimale e la frequenza di raccolta di questo indicatore";
$lang['dashboard']['help_mod3'] = "Puoi cliccare su \"" . $lang['dashboard']['all_value'] . "\" per visualizzare tutti i valori di questo indicatore per questa scala";
$lang['dashboard']['help_mod4'] = "Se il riepilogo non ti soddisfa, puoi cliccare su \"modifica i parametri\" per modificarlo";
$lang['dashboard']['help_mod5'] = "Devi assolutamente inserire un valore numerico compreso entro i valori minimali e massimali previsti per questo indicatore";
$lang['dashboard']['help_mod6'] = "I campi contrassegnati da un asterisco sono obbligatori";


$lang['dashboard']['help_rap1'] = "Il rapporto è pubblicato in formato pdf e leggibile con Acrobat reader";
$lang['dashboard']['help_rap2'] = "Scegli tra le differenti opzioni proposte qui sotto per pubblicare il tuo rapporto";
$lang['dashboard']['help_rap3'] = "Puoi annullare la pubblicazione del rapporto in ogni momento cliccando su annulla";


$lang['dashboard']['help_det2'] = "Puoi aggiungere un valore a questa coppia indicatore/scala cliccando sull'icona di aggiuntaassociata, situata nella parte alta della pagina";
$lang['dashboard']['help_det3'] = "Puoi modificare un valore cliccando sull'icona di modifica ad esso associata";
$lang['dashboard']['help_det4'] = "Puoi eliminare un valore cliccando sull'icona di eliminazione ad esso associata";
$lang['dashboard']['help_det1'] = "Attenzione, un valore è associato a un indicatore ma anche ad una scala";
$lang['dashboard']['help_det5'] = "Per visualizzare le informazioni generali di un indicatore, di regolamentazione, fornitori, e i criteri di valutazione, cliccare su visualizzare queste informazioni situato in basso nella pagina.";


$lang['dashboard']['help_sup1'] = "Cliccando su convalidare, il valore è definitivamente eliminato.";
$lang['dashboard']['help_sup2'] = "Se desideri semplicemente disattivare il valore, posizionalo in stato\"brogliaccio\" all'interno di modificare i valori.";
?>

==> dl.php?src=linea21_2_0_0.zip: linea21/languages/it/lang_dashboard.utf-8.php <==
<?php
/**
 * @package linea21\languages\it
 * @author $Author$ - Alessandra Rossi & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['dashboard']['section'] = "pannello di controllo";

/*	nommage des modules
 *  	*/
$lang['dashboard']['name'] = "valore";
$lang['dashboard']['name_pluriel'] = 'valore(i)';
$lang['dashboard']['confirm_add'] = "Aggiunta di un valore realizzata con successo\n";
$lang['dashboard']['confirm_mod'] = "Modifica del valore realizzata con successo\n";
$lang['dashboard']['confirm_sup'] = "Eliminazione del valore realizzata con successo\n";




/*	nommage public
 *  	*/
$lang['dashboard']['list_public']="Pannello di controllo";

$lang['dashboard']['h1_public_comment']="Il pannello di controllo rappresenta il bilancio di sviluppo sostenibile della vostra città (filtrato per scala).<br />";
$lang['dashboard']['h1_public_comment_anim']="Il pannello di controllo rappresenta il bilancio di sviluppo sostenibile della vostra città.<br />";

$lang['dashboard']['mode_aff']="Modalità di visualizzazione";
$lang['dashboard']['mode_by_project']="Project view"; // @todo translation
$lang['dashboard']['mode_by_finality']="Finality view"; // @todo translation
$lang['dashboard']['mode_aff_info']="Informazioni generali";
$lang['dashboard']['mode_aff_evaluation']="Criteri di valutazione";
$lang['dashboard']['mode_aff_provider']="Fornitore";
$lang['dashboard']['mode_aff_rules']="Regolamentazione";
$lang['sdi']['goal_public']="Gli obiettivi di chi avete eletto";
$lang['sdi']['consulting_public']="Consigli per migliorare questo indicatore";

$lang['dashboard']['tab-attached']='Strategic indicators'; // @todo translation
$lang['dashboard']['tab-not-attached']='Common indicators'; // @todo translation
$lang['dashboard']['tab-all']='All'; // @todo translation

$lang['dashboard']['export_values']='Export values'; // @todo translation

/* informations affichages tableau
 * */
$lang['dashboard']['list_public_summary']="Valori degli indicatori relativi ai %s";
$lang['dashboard']['graphic_value']="valore grafico";
$lang['dashboard']['numeric_value']="valore numerico";
$lang['dashboard']['tendencies_value']="tendenze";
$lang['dashboard']['label_value']="etichetta dell'indicatore";

$lang['dashboard']['evaluation_values_summary']="Valori dei criteri di valutazione per l'indicatore corrente";
$lang['dashboard']['all_values_summary']="Sommario dei valori dell'indicatore corrente";

$lang['dashboard']['multivalue_label']="label"; // @todo translation
$lang['dashboard']['multivalue_value']="value"; // @todo translation
$lang['dashboard']['multivalue_distribution']="distribution"; // @todo translation
$lang['dashboard']['multivalue_total']="total"; // @todo translation
$lang['dashboard']['global_rate']="Global rate"; // @todo translation
$lang['dashboard']['cagr']="<abbr title=\"Compound Annual Growth Rate\">CAGR</abbr>"; // @todo translation

$lang['dashboard']['to_detail_chart']="see pie chart"; // @todo translation
$lang['dashboard']['negative_values_notice']="[negative values not displayed]"; // @todo translation

/*	nommage rubrique module
 *  	*/
$lang['dashboard']['add'] = "Aggiunta di una " . $lang['dashboard']['name'];
$lang['dashboard']['rap'] = "Pubblicazione di un rapporto globale";
$lang['dashboard']['mod'] = "Modifica del valore";
$lang['dashboard']['sup'] = "Eliminazione di una " . $lang['dashboard']['name'];
$lang['dashboard']['det'] = "Valori dell'indicatore";
$lang['dashboard']['list'] = "Pannello di controllo ";


/*	nommage rubrique add / mod /det
 *  	*/
$lang['dashboard']['add_title1'] = "Inserimento della nuova " . $lang['dashboard']['name'];
$lang['dashboard']['recap_commment'] = "nessun commento";
$lang['dashboard']['confirmation'] = "conferma l'iscrizione";


/*	nommage rubrique sup
 *  	*/
$lang['dashboard']['sup_value_warning'] = "Sei sicuro di voler sopprimere definitivamente questa " . $lang['dashboard']['name'] . "?";


/*	nommage élément rubrique

*  	*/
$lang['dashboard']['value'] = "valore dell'indicatore";
$lang['dashboard']['threshold_value']="valore soglia";
$lang['dashboard']['historic'] = "Bilancio dell'indicatore";
$lang['dashboard']['rep_graph'] = "Rappresentazione grafica dell'indicatore";
$lang['dashboard']['sdi_info'] = "nome dell'indicatore";
$lang['dashboard']['scale'] = "scala di misura del valore";
$lang['dashboard']['date'] = "data di pubblicazione";
$lang['dashboard']['day'] = "giorno";
$lang['dashboard']['month'] = "mese";
$lang['dashboard']['year'] = "anno";
$lang['dashboard']['rate'] = "percentage"; // @todo translation
$lang['dashboard']['comment'] = "comment"; // @todo translation
$lang['dashboard']['comment_status'] = "comment status"; // @todo translation
$lang['dashboard']['public'] = "public"; // @todo translation
$lang['dashboard']['private'] = "private"; // @todo translation
$lang['dashboard']['previous_value'] = "previous value : %s"; // @todo translation

/*	nommage quickbox
 *  	*/
$lang['dashboard']['qb_add_title'] = " ultime aggiunte effettuate nel : ";
$lang['dashboard']['qb_mod_title'] = " ultime modifiche effettuate nel : ";


/*	divers
 *  	*/
$lang['dashboard']['select_choice'] = "-- Scegli nella lista sottostante --";
$lang['dashboard']['facultatif'] = "facoltativo";
$lang['dashboard']['aff_dashboard_e'] = "Visualizzare i criteri di valutazione";
$lang['dashboard']['aff_dashboard_r'] = "Visualizzare le referenze regolamentari";
$lang['dashboard']['aff_dashboard_p'] = "Visualizzare le coordinate del fornitore";
$lang['dashboard']['novalue'] = "Nessun valore è disponibile";
$lang['dashboard']['value_tendance'] = "Tendenza globale dell'indicatore";
$lang['dashboard']['tendance_asc'] = "ascendente";
$lang['dashboard']['tendance_desc'] = "discendente";
$lang['dashboard']['all_value'] = "Insieme dei valori per questo indicatore";
$lang['dashboard']['barre'] = "Posizionamento dell'indicatore in rapporto al suo valore soglia";
$lang['dashboard']['global_value'] = "valore globale";
$lang['dashboard']['det_sdi'] = "visualizzare le informazioni generali dell'indicatore";
$lang['dashboard']['det_sdi2'] = "Informazioni generali";
$lang['dashboard']['download_chart'] = "download chart"; // @todo translation

/*	messages
 *  	*/


$lang['dashboard']['object_notvalue'] = "Devi assolutamente inserire un valore numerico per questo indicatore.";
$lang['dashboard']['object_notgoodvalue'] = "Devi assolutamente inserire un valore compreso nei limiti di misura.";


/*	rubrique d'aide
 *  	*/
$lang['dashboard']['help_add1'] = "Per aggiungere un valore, devi inserire ciascuno di questi parametri nel modulo qui sotto";
$lang['dashboard']['help_add2'] = "Puoi cliccare su \"informazioni di misura\" per ottenere i valori soglia minimale, massimale e la frequenza di raccolta di questo indicatore";
$lang['dashboard']['help_add3'] = "Puoi cliccare su \"" . $lang['dashboard']['all_value'] . "\" per visualizzare tutti i valori di questo indicatore per questa scala";
$lang['dashboard']['help_add4'] = "Se il riepilogo non ti soddisfa, puoi cliccare su \"modifica i parametri\" per modificarlo";
$lang['dashboard']['help_add5'] = "Devi assolutamente inserire un valore numerico compreso tra i valori minimali e massimali previsti da questo indicatore";
$lang['dashboard']['help_add6'] = "I campi contrassegnati da un asterisco sono obbligatori";


$lang['dashboard']['help_list1'] = "Per visualizzare i valori di una coppia indicatore/scala nel dettaglio, clicca sul nome dell'indicatore.";
$lang['dashboard']['help_list2'] = "Puoi aggiungere un valore a una coppia indicatore/scala cliccando sull'icona d'aggiunta ad essa associata.";
$lang['dashboard']['help_list3'] = "Puoi selezionare un'altra scala, il pannello di controllo verrà aggiornato : l'insieme degli indicatori di questa scala apparirà sul pannello di controllo.";
$lang['dashboard']['help_list4'] = "Ogni indicatore è associato a un contatore che permette una visione globale del pannello di controllo per una data scala : se il cursore del contatore è al di là della soglia, l'ultimo valore registarto per questo indicatore ha superato la soglia stabilita";
$lang['dashboard']['help_list5'] = "Se l'indicatore, per una data scala, conta più di due valori, un'icona di trend apparirà accanto al contatore";
$lang['dashboard']['help_list6'] = "L'ultimo valore dell'indicatore, per una data scala, è richiamato accanto al contatore.";
$lang['dashboard']['help_list7'] = "Un contatore globale è presente nella parte alta della pagina e permette una visione globale del pannello di controllo per una data scala.";
$lang['dashboard']['help_list8'] = "Trucco : lasciare immobile il cursore sui differenti elementi della pagina mostrerà delle informazioni complementari.";


$lang['dashboard']['help_mod1'] = "Per modificare un valore, puoi modificare ciascuno di questi parametri nel modulo qui sotto";
$lang['dashboard']['help_mod2'] = "Puoi cliccare su \"informazioni di misura\" per ottenere i valori soglia minimale, massimale e la frequenza di raccolta di questo indicatore";
$lang['dashboard']['help_mod3'] = "Puoi cliccare su \"" . $lang['dashboard']['all_value'] . "\" per visualizzare tutti i valori di questo indicatore per questa scala";
$lang['dashboard']['help_mod4'] = "Se il riepilogo non ti soddisfa, puoi cliccare su \"modifica i parametri\" per modificarlo";
$lang['dashboard']['help_mod5'] = "Devi assolutamente inserire un valore numerico compreso entro i valori minimali e massimali previsti per questo indicatore";
$lang['dashboard']['help_mod6'] = "I campi contrassegnati da un asterisco sono obbligatori";


$lang['dashboard']['help_rap1'] = "Il rapporto è pubblicato in formato pdf o Word e leggibile con Acrobat reader, Microsoft Office o LibreOffice";
$lang['dashboard']['help_rap2'] = "Scegli tra le differenti opzioni proposte qui sotto per pubblicare il tuo rapporto";
$lang['dashboard']['help_rap3'] = "Puoi annullare la pubblicazione del rapporto in ogni momento cliccando su annulla";


$lang['dashboard']['help_det2'] = "Puoi aggiungere un valore a questa coppia indicatore/scala cliccando sull'icona di aggiuntaassociata, situata nella parte alta della pagina";
$lang['dashboard']['help_det3'] = "Puoi modificare un valore cliccando sull'icona di modifica ad esso associata";
$lang['dashboard']['help_det4'] = "Puoi eliminare un valore cliccando sull'icona di eliminazione ad esso associata";
$lang['dashboard']['help_det1'] = "Attenzione, un valore è associato a un indicatore ma anche ad una scala";
$lang['dashboard']['help_det5'] = "Per visualizzare le informazioni generali di un indicatore, di regolamentazione, fornitori, e i criteri di valutazione, cliccare su visualizzare queste informazioni situato in basso nella pagina.";


$lang['dashboard']['help_sup1'] = "Cliccando su convalidare, il valore è definitivamente eliminato.";
$lang['dashboard']['help_sup2'] = "Se desideri semplicemente disattivare il valore, posizionalo in stato\"brogliaccio\" all'interno di modificare i valori.";
?>
